@@ -42,6 +42,7 @@ typedef unsigned __int64    uint64_t;
 #define PY_COMPAT_CHECK PyString_Check
 #define PY_DECODELATIN1(pt, size, error) PyString_Decode(pt, size, "latin-1", error)
 #define PYLONG_FROMLONGLONG(integer) PyInt_FromSsize_t((ssize_t) integer)
+#define PyUnicode_InternInPlace(__straddr) (void) (__straddr)
 
 #endif
 
@@ -1002,6 +1003,10 @@ static PyObject * unpackb(
                         Py_DECREF(obj);
                         return NULL;
                     }
+                    else if (PyUnicode_CheckExact(key))
+                    {
+                        PyUnicode_InternInPlace(&key);
+                    }
 
                     value = unpackb(pt, end, decode, ignore_decode_errors);
 
@@ -1096,6 +1101,10 @@ static PyObject * unpackb(
                     {
                         break;
                     }
+                    else if (PyUnicode_CheckExact(key))
+                    {
+                        PyUnicode_InternInPlace(&key);
+                    }
 
                     value = unpackb(pt, end, decode, ignore_decode_errors);
 
