@@ -11,6 +11,7 @@ if sys.version_info[0] == 3:
     PY_CONVERT = int
     INT_TYPES = int
     STR = str
+    intern = sys.intern
 
     def dict_items(d):
         return d.items()
@@ -282,6 +283,8 @@ def _unpack(qp, pos, end, decode, ignore_decode_errors):
         for _ in range(tp - 0xf3):
             pos, key = _unpack(qp, pos, end, decode, ignore_decode_errors)
             pos, value = _unpack(qp, pos, end, decode, ignore_decode_errors)
+            if isinstance(key, str):
+                intern(key)
             qp_map[key] = value
         return pos, qp_map
 
@@ -300,6 +303,8 @@ def _unpack(qp, pos, end, decode, ignore_decode_errors):
         while pos < end and PY_CONVERT(qp[pos]) != N_CLOSE_MAP:
             pos, key = _unpack(qp, pos, end, decode, ignore_decode_errors)
             pos, value = _unpack(qp, pos, end, decode, ignore_decode_errors)
+            if isinstance(key, str):
+                intern(key)
             qp_map[key] = value
         return pos + 1, qp_map
 
